==> nextcloud-26.0.7p0.tgz: nextcloud/apps/encryption/l10n/zh_HK.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "缺少恢復密鑰密碼",
    "Please repeat the recovery key password" : "請您再輸入新的還原密鑰密碼一次",
    "Repeated recovery key password does not match the provided recovery key password" : "輸入的還原密鑰密碼與設定的並不相符",
    "Recovery key successfully enabled" : "還原密鑰已成功開啟",
    "Could not enable recovery key. Please check your recovery key password!" : "無法啟用還原密鑰。請檢查您的還原密鑰密碼!",
    "Recovery key successfully disabled" : "還原密鑰已成功停用",
    "Could not disable recovery key. Please check your recovery key password!" : "無法停用還原密鑰。請檢查您的還原密鑰密碼!",
    "Missing parameters" : "缺少參數",
    "Please provide the old recovery password" : "請提供舊的還原密碼",
    "Please provide a new recovery password" : "請提供新的還原密碼",
    "Please repeat the new recovery password" : "請您再輸入新的還原密碼",
    "Password successfully changed." : "成功變更密碼。",
    "Could not change the password. Maybe the old password was not correct." : "無法變更密碼，或許是輸入的舊密碼不正確。",
    "Recovery Key disabled" : "還原密鑰停用",
    "Recovery Key enabled" : "還原密鑰啟用",
    "Could not enable the recovery key, please try again or contact your administrator" : "無法啟用還原密鑰功能，請重試或聯絡系統管理員",
    "Could not update the private key password." : "無法更新私人密鑰密碼",
    "The old password was not correct, please try again." : "舊密碼不正確，請再試一次",
    "The current log-in password was not correct, please try again." : "目前登入的密碼不正確，請再試一次",
    "Private key password successfully updated." : "私人密鑰密碼已成功更新。",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "無效的加密應用程序私鑰。請在您的個人設定中更新您的私鑰密碼，以恢復對加密文件的訪問。",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "已啟用加密應用，但是你的加密密鑰沒有初始化。請重新登出並登入系統一次。",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "請啟用管理員設定中的伺服器端加密，以使用加密模組。",
    "Encryption app is enabled and ready" : "加密應用程式已啟用並準備就緒",
    "Bad Signature" : "壞的簽名",
    "Missing Signature" : "缺少簽名",
    "one-time password for server-side-encryption" : "用於伺服器端加密的一次性密碼",
    "Encryption password" : "加密密碼",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "管理啟用了伺服器端加密 您的檔案已使用密碼 <strong>%s</strong> 加密。",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "管理員啟用了伺服器端加密。您的檔案已使用密碼 \"%s\" 加密。",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "請登錄到網絡界面，轉到您個人設置的「安全」部分，並通過在「舊登錄密碼」字段中輸入此密碼和您當前的登錄密碼來更新您的登入密碼。",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法解密這個檔案，也許這是分享的檔案。請讓檔案所有者與您重新共享檔案。",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法檢視這個檔案，或許這是分享的檔案。請讓檔案所有者與您重新共享檔案。",
    "Default encryption module" : "默認加密模組",
    "Default encryption module for server-side encryption" : "伺服器端的默認加密模組",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "您需要在管理員設置中啟用服務器端加密才能使用此加密模塊您需要在管理員設置中啟用服務器端加密。啟用後，此模塊將透明地加密您的所有文件。加密基於 AES 256 密鑰。\n該模塊不會觸及現有文件，啟用伺服器端加密後只會對新檔案進行加密。也不可能再次禁用加密並切換回未加密的系統。\n在您決定啟用伺服器端加密之前，請閱讀文檔以了解所有含義。一旦啟用，此模塊將透明地加密您的所有文件。加密基於 AES 256 密鑰。\n該模塊不會觸及現有文件，啟伺服器端加密後只會對新文件進行加密。也不可能再次禁用加密並切換回未加密的系統。\n在您決定啟用伺服器端加密之前，請閱讀文檔以了解所有含義。",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "已啟用加密應用，但是你的加密密鑰沒有初始化。請重新登出並登入系統一次。",
    "Encrypt the home storage" : "加密主要存儲空間",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "請啟用這個功能以用來加密主要儲存空間的檔案，否則只有再外部儲存的檔案會加密",
    "Enable recovery key" : "啟用還原密鑰",
    "Disable recovery key" : "關閉還原密鑰",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "加密密鑰是另一種加密檔案方式，當用戶忘記密碼時，可以用還原密鑰來還原檔案",
    "Recovery key password" : "還原密鑰密碼",
    "Repeat recovery key password" : "再輸入還原密鑰密碼一次",
    "Change recovery key password:" : "更新還原密鑰密碼：",
    "Old recovery key password" : "舊的還原密鑰密碼",
    "New recovery key password" : "新的還原密鑰密碼",
    "Repeat new recovery key password" : "再輸入新的還原密鑰密碼一次",
    "Change Password" : "變更密碼",
    "Basic encryption module" : "基本加密模組",
    "Your private key password no longer matches your log-in password." : "您的私人密鑰密碼不符合您的登入密碼",
    "Set your old private key password to your current log-in password:" : "設定您的舊私人密鑰密碼到您現在的登入密碼：",
    " If you don't remember your old password you can ask your administrator to recover your files." : "如果您忘記舊密碼，可以請求管理員協助取回檔案。",
    "Old log-in password" : "舊登入密碼",
    "Current log-in password" : "目前的登入密碼",
    "Update Private Key Password" : "更新私人密鑰密碼",
    "Enable password recovery:" : "啟用密碼還原﹕",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "啟用這個選項將會允許您因忘記密碼但需要存取您的加密檔案",
    "Enabled" : "已啓用",
    "Disabled" : "已停用",
    "In order to use this encryption module you need to enable server-side\n\t\tencryption in the admin settings. Once enabled this module will encrypt\n\t\tall your files transparently. The encryption is based on AES 256 keys.\n\t\tThe module won't touch existing files, only new files will be encrypted\n\t\tafter server-side encryption was enabled. It is also not possible to\n\t\tdisable the encryption again and switch back to a unencrypted system.\n\t\tPlease read the documentation to know all implications before you decide\n\t\tto enable server-side encryption." : "為了使用此加密模組，您需要啟用伺服器端\n管理員設置中的加密設定。啟用後，該模組將加密您的所有之後傳輸的檔案。此加密方式使用AES 256密鑰。\n該模組不會觸及已存在的檔案，只會加密新處理的檔案\n啟用伺服器端加密後。也不可能\n再次停用加密，然後切換回未加密的系統。\n在決定啟用伺服器端加密之前，請閱讀文檔以了解所有含義。",
    "Hey there,\n\nThe administration enabled server-side-encryption. Your files were encrypted using the password \"%s\".\n\nPlease login to the web interface, go to the section \"Basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password.\n\n" : "嗨，\n\n系管理員啟用了伺服器端的加密功能，您的檔案已使用密碼 \"%s\" 加密。\n\n請使用網頁介面登入，到您個人設定中的「基本加密模組」，並在「舊登入密碼」欄位輸入此密碼與您目前的登入密碼來更新加密密碼。\n",
    "The share will expire on %s." : "這個分享將會於 %s 過期。",
    "Cheers!" : "太棒了！",
    "Hey there,<br><br>The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"Basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password.<br><br>" : "嗨，<br><br>管理員啟用了伺服器端加密的功能，您的檔案已使用密碼<strong>%s</strong>加密。<br><br>請使用網頁界面 登入，到您個人設定中的「基本加密模組」，並在「舊登入密碼」欄位輸入此密碼與您目前的登入密碼來更新加密密碼。<br><br>",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password." : "請登錄到網絡界面，轉到您個人設置的“安全”部分，並通過在“舊登錄密碼”字段中輸入此密碼和您當前的登錄密碼來更新您的登入密碼。"
},
"nplurals=1; plural=0;");

==> nextcloud-27.1.5.tgz: nextcloud/apps/encryption/l10n/zh_HK.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "缺少恢復密鑰密碼",
    "Please repeat the recovery key password" : "請您再輸入新的還原密鑰密碼一次",
    "Repeated recovery key password does not match the provided recovery key password" : "輸入的還原密鑰密碼與設定的並不相符",
    "Recovery key successfully enabled" : "還原密鑰已成功開啟",
    "Could not enable recovery key. Please check your recovery key password!" : "無法啟用還原密鑰。請檢查您的還原密鑰密碼!",
    "Recovery key successfully disabled" : "還原密鑰已成功停用",
    "Could not disable recovery key. Please check your recovery key password!" : "無法停用還原密鑰。請檢查您的還原密鑰密碼!",
    "Missing parameters" : "缺少參數",
    "Please provide the old recovery password" : "請提供舊的還原密碼",
    "Please provide a new recovery password" : "請提供新的還原密碼",
    "Please repeat the new recovery password" : "請您再輸入新的還原密碼",
    "Password successfully changed." : "成功變更密碼。",
    "Could not change the password. Maybe the old password was not correct." : "無法變更密碼，或許是輸入的舊密碼不正確。",
    "Recovery Key disabled" : "還原密鑰停用",
    "Recovery Key enabled" : "還原密鑰啟用",
    "Could not enable the recovery key, please try again or contact your administrator" : "無法啟用還原密鑰功能，請重試或聯絡系統管理員",
    "Could not update the private key password." : "無法更新私人密鑰密碼",
    "The old password was not correct, please try again." : "舊密碼不正確，請再試一次",
    "The current log-in password was not correct, please try again." : "目前登入的密碼不正確，請再試一次",
    "Private key password successfully updated." : "私人密鑰密碼已成功更新。",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "無效的加密應用程序私鑰。請在您的個人設定中更新您的私鑰密碼，以恢復對加密文件的訪問。",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "已啟用加密應用，但是你的加密密鑰沒有初始化。請重新登出並登入系統一次。",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "請啟用管理員設定中的伺服器端加密，以使用加密模組。",
    "Encryption app is enabled and ready" : "加密應用程式已啟用並準備就緒",
    "Bad Signature" : "壞的簽名",
    "Missing Signature" : "缺少簽名",
    "one-time password for server-side-encryption" : "用於伺服器端加密的一次性密碼",
    "Encryption password" : "加密密碼",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "管理啟用了伺服器端加密 您的檔案已使用密碼 <strong>%s</strong> 加密。",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "管理員啟用了伺服器端加密。您的檔案已使用密碼 \"%s\" 加密。",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "請登錄到網絡界面，轉到您個人設置的「安全」部分，並通過在「舊登錄密碼」字段中輸入此密碼和您當前的登錄密碼來更新您的登入密碼。",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法解密這個檔案，也許這是分享的檔案。請讓檔案所有者與您重新共享檔案。",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法檢視這個檔案，或許這是分享的檔案。請讓檔案所有者與您重新共享檔案。",
    "Default encryption module" : "默認加密模組",
    "Default encryption module for server-side encryption" : "伺服器端的默認加密模組",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "您需要在管理員設置中啟用服務器端加密才能使用此加密模塊您需要在管理員設置中啟用服務器端加密。啟用後，此模塊將透明地加密您的所有文件。加密基於 AES 256 密鑰。\n該模塊不會觸及現有文件，啟用伺服器端加密後只會對新檔案進行加密。也不可能再次禁用加密並切換回未加密的系統。\n在您決定啟用伺服器端加密之前，請閱讀文檔以了解所有含義。一旦啟用，此模塊將透明地加密您的所有文件。加密基於 AES 256 密鑰。\n該模塊不會觸及現有文件，啟伺服器端加密後只會對新文件進行加密。也不可能再次禁用加密並切換回未加密的系統。\n在您決定啟用伺服器端加密之前，請閱讀文檔以了解所有含義。",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "已啟用加密應用，但是你的加密密鑰沒有初始化。請重新登出並登入系統一次。",
    "Encrypt the home storage" : "加密主要存儲空間",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "請啟用這個功能以用來加密主要儲存空間的檔案，否則只有再外部儲存的檔案會加密",
    "Enable recovery key" : "啟用還原密鑰",
    "Disable recovery key" : "關閉還原密鑰",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "加密密鑰是另一種加密檔案方式，當用戶忘記密碼時，可以用還原密鑰來還原檔案",
    "Recovery key password" : "還原密鑰密碼",
    "Repeat recovery key password" : "再輸入還原密鑰密碼一次",
    "Change recovery key password:" : "更新還原密鑰密碼：",
    "Old recovery key password" : "舊的還原密鑰密碼",
    "New recovery key password" : "新的還原密鑰密碼",
    "Repeat new recovery key password" : "再輸入新的還原密鑰密碼一次",
    "Change Password" : "變更密碼",
    "Basic encryption module" : "基本加密模組",
    "Your private key password no longer matches your log-in password." : "您的私人密鑰密碼不符合您的登入密碼",
    "Set your old private key password to your current log-in password:" : "設定您的舊私人密鑰密碼到您現在的登入密碼：",
    " If you don't remember your old password you can ask your administrator to recover your files." : "如果您忘記舊密碼，可以請求管理員協助取回檔案。",
    "Old log-in password" : "舊登入密碼",
    "Current log-in password" : "目前的登入密碼",
    "Update Private Key Password" : "更新私人密鑰密碼",
    "Enable password recovery:" : "啟用密碼還原﹕",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "啟用這個選項將會允許您因忘記密碼但需要存取您的加密檔案",
    "Enabled" : "已啓用",
    "Disabled" : "已停用",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password." : "請登錄到網絡界面，轉到您個人設置的“安全”部分，並通過在“舊登錄密碼”字段中輸入此密碼和您當前的登錄密碼來更新您的登入密碼。",
    "In order to use this encryption module you need to enable server-side\n\t\tencryption in the admin settings. Once enabled this module will encrypt\n\t\tall your files transparently. The encryption is based on AES 256 keys.\n\t\tThe module won't touch existing files, only new files will be encrypted\n\t\tafter server-side encryption was enabled. It is also not possible to\n\t\tdisable the encryption again and switch back to a unencrypted system.\n\t\tPlease read the documentation to know all implications before you decide\n\t\tto enable server-side encryption." : "為了使用此加密模組，您需要啟用伺服器端\n管理員設置中的加密設定。啟用後，該模組將加密您的所有之後傳輸的檔案。此加密方式使用AES 256密鑰。\n該模組不會觸及已存在的檔案，只會加密新處理的檔案\n啟用伺服器端加密後。也不可能\n再次停用加密，然後切換回未加密的系統。\n在決定啟用伺服器端加密之前，請閱讀文檔以了解所有含義。"
},
"nplurals=1; plural=0;");
